@@ -24,11 +24,11 @@ Template::Flute::PDF - PDF generator for HTML templates
 
 =head1 VERSION
 
-Version 0.0030
+Version 0.0040
 
 =cut
 
-our $VERSION = '0.0030';
+our $VERSION = '0.0040';
 
 =head1 SYNOPSIS
 
@@ -130,6 +130,38 @@ use constant FONT_SIZE => '12';
 use constant PAGE_SIZE => 'a4';
 use constant MARGINS => (20, 20, 50, 20);
 
+# font map for PDF core fonts (see PDF::API2::Resource::Font::CoreFont)
+our %font_map = (Courier => {Bold => 'Courier-Bold',
+			     BoldItalic => 'Courier-BoldOblique',
+			     Italic => 'Courier-Oblique',
+			     Roman => 'Courier',
+		 },
+		 Georgia => {Bold => 'Georgia,Bold',
+			     BoldItalic => 'Georgia,BoldItalic',
+			     Italic => 'Georgia,Italic',
+			     Roman => 'Georgia',
+		 },
+		 Helvetica => {Bold => 'Helvetica-Bold',
+			       BoldItalic => 'Helvetica-BoldOblique',
+			       Italic => 'Helvetica-Oblique',
+			       Roman => 'Helvetica',
+		 },
+		 Symbol => {},
+		 Times => {Bold => 'Times-Bold',
+			   BoldItalic => 'Times-BoldItalic',
+			   Roman => 'Times',
+			   Italic => 'Times-Italic'
+		 },
+		 Verdana => {Bold => 'Verdana,Bold',
+			     BoldItalic => 'Verdana,BoldItalic',
+			     Italic => 'Verdana,Italic',
+			     Roman => 'Verdana',
+		 },
+		 Webdings => {},
+		 Wingdings => {},
+		 ZapfDingbats => {},
+    );
+
 sub new {
 	my ($proto, @args) = @_;
 	my ($class, $self);
@@ -186,9 +218,16 @@ Processes HTML template and creates PDF file.
 =cut
 
 sub process {
-	my ($self, $file) = @_;
-	my ($font, $table);
+	my $self = shift;
+	my ($file, $font, $table);
 
+    if (@_) {
+        $file = shift;
+    }
+    else {
+        $file = $self->{file};
+    }
+    
 	$self->{cur_page} = 1;
 
 	$self->{border_left} = to_points($self->{margin_left}, 'pt');
@@ -225,7 +264,7 @@ sub process {
 		$obj = new Template::Flute::PDF::Import;
 		
 		unless ($ret = $obj->import(%import_parms)) {
-			die "Failed to import file $self->{import}.\n";
+			die "Failed to import file $import_parms{file}.\n";
 		}
 
 #		if ($self->{verbose} || 1) {
@@ -423,19 +462,37 @@ sub content_width {
 	return $width;
 }
 
-=head2 font NAME [weight]
+=head2 font NAME [weight] [style]
 
-Returns PDF::API2 font object for font NAME, WEIGHT is optional.
+Returns PDF::API2 font object for font NAME, WEIGHT and STYLE are optional.
 
 =cut
 	
 sub font {
-	my ($self, $name, $weight) = @_;
+	my ($self, $name, $weight, $style) = @_;
 	my ($key, $obj);
 
+    if ($weight eq 'normal') {
+        # default font weight
+        $weight = '';
+    }
+
 	# determine font name from supplied name and optional weight
 	if ($weight) {
-		$key = "$name-$weight";
+	    if ($style) {
+            $key = "$name-$weight$style";
+        }
+        else {
+            $key = "$name-$weight";
+        }
+	}
+	elsif ($style) {
+	    if (exists $font_map{$name}->{$style}) {
+            $key = $font_map{$name}->{$style};
+	    }
+	    else {
+            $key = "$name-$style";
+	    }
 	}
 	else {
 		$key = $name;
@@ -511,7 +568,7 @@ and INHERIT flag.
 sub setup_text_props {
 	my ($self, $elt, $selector, $inherit) = @_;
 	my ($props, %borders, %padding, %margins, %offset, $fontsize, $fontfamily,
-		$fontweight, $txeng);
+		$fontweight, $fontstyle, $txeng);
 
 	my $class = $elt->att('class') || '';
 	my $id = $elt->att('id') || '';
@@ -554,8 +611,16 @@ sub setup_text_props {
 	else {
 		$fontweight = $self->{fontweight};
 	}
-	
-	$self->{font} = $self->font($fontfamily, $fontweight);
+
+    if ($props->{font}->{style}) {
+        $fontstyle = $props->{font}->{style};
+    }
+    elsif ($gi eq 'i') {
+        $fontstyle = 'Italic';
+    }
+
+	$self->{font} = $self->font($fontfamily, $fontweight,
+	    $fontstyle);
 	
 	$txeng->font($self->{font}, $fontsize);
 
@@ -1122,7 +1187,22 @@ sub _font_select {
 	return $fonts[0];
 }
 
+=head1 SUPPORTED HTML/CSS SYNTAX
 
+This is an incomplete list of supported HTML/CSS syntax.
+
+=head2 HTML tags
+
+<i>
+    
+=head2 font-weight
+
+The values "normal" and "bold" are supported.
+
+=head2 style
+
+The HTML attribute "style" is not supported.
+    
 =head1 AUTHOR
 
 Stefan Hornburg (Racke), <racke@linuxia.de>
